@@ -9,7 +9,7 @@ use Carp;
 use List::Util qw(first);
 use WebService::Linode::Base;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 our @ISA     = ("WebService::Linode::Base");
 our $AUTOLOAD;
 
@@ -230,10 +230,6 @@ __END__
 
 WebService::Linode - Perl Interface to the Linode.com API.
 
-=head1 VERSION
-
-Version 0.11
-
 =head1 SYNOPSIS
 
     my $api = WebService::Linode->new( apikey => 'your api key here');
@@ -243,18 +239,12 @@ Version 0.11
 This module implements the Linode.com api methods.  Linode methods have had
 dots replaced with underscores to generate the perl method name.  All keys
 and parameters have been lower cased but returned data remains otherwise the
-same.  For additional information see L<http://www.linode.com/api/autodoc.cfm>
+same.  For additional information see L<http://www.linode.com/api/>
 
 =head1 Methods from the Linode API
 
 =head3 avail_stackscripts
 
-Required Parameters:
-
-=over 4
-
-=back
-
 Optional Parameters:
 
 =over 4
@@ -269,12 +259,6 @@ Optional Parameters:
 
 =head3 avail_kernels
 
-Required Parameters:
-
-=over 4
-
-=back
-
 Optional Parameters:
 
 =over 4
@@ -287,12 +271,6 @@ Optional Parameters:
 
 =head3 avail_linodeplans
 
-Required Parameters:
-
-=over 4
-
-=back
-
 Optional Parameters:
 
 =over 4
@@ -303,26 +281,8 @@ Optional Parameters:
 
 =head3 avail_datacenters
 
-Required Parameters:
-
-=over 4
-
-=back
-
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 avail_distributions
 
-Required Parameters:
-
-=over 4
-
-=back
-
 Optional Parameters:
 
 =over 4
@@ -377,12 +337,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 domain_update
 
 Required Parameters:
@@ -423,12 +377,6 @@ Optional Parameters:
 
 =head3 domain_list
 
-Required Parameters:
-
-=over 4
-
-=back
-
 Optional Parameters:
 
 =over 4
@@ -481,12 +429,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 domain_resource_update
 
 Required Parameters:
@@ -547,12 +489,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_create
 
 Required Parameters:
@@ -567,12 +503,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_reboot
 
 Required Parameters:
@@ -601,12 +531,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_boot
 
 Required Parameters:
@@ -637,12 +561,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_clone
 
 Required Parameters:
@@ -659,12 +577,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_shutdown
 
 Required Parameters:
@@ -675,12 +587,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_delete
 
 Required Parameters:
@@ -755,12 +661,6 @@ Optional Parameters:
 
 =head3 linode_list
 
-Required Parameters:
-
-=over 4
-
-=back
-
 Optional Parameters:
 
 =over 4
@@ -823,12 +723,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_config_update
 
 Required Parameters:
@@ -907,12 +801,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_disk_resize
 
 Required Parameters:
@@ -927,12 +815,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_disk_createfromdistribution
 
 Required Parameters:
@@ -971,12 +853,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_disk_delete
 
 Required Parameters:
@@ -989,12 +865,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_disk_update
 
 Required Parameters:
@@ -1057,12 +927,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_ip_addprivate
 
 Required Parameters:
@@ -1073,12 +937,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 linode_ip_list
 
 Required Parameters:
@@ -1153,12 +1011,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 stackscript_update
 
 Required Parameters:
@@ -1189,12 +1041,6 @@ Optional Parameters:
 
 =head3 stackscript_list
 
-Required Parameters:
-
-=over 4
-
-=back
-
 Optional Parameters:
 
 =over 4
@@ -1249,12 +1095,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 nodebalancer_config_update
 
 Required Parameters:
@@ -1343,12 +1183,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head3 nodebalancer_node_update
 
 Required Parameters:
@@ -1403,12 +1237,6 @@ Required Parameters:
 
 =back
 
-Optional Parameters:
-
-=over 4
-
-=back
-
 =head1 Additional Helper Methods
 
 These methods are deprecated and will be going away.
